@@ -1,6 +1,7 @@
 #!/usr/bin/env python3
 
 import string
+import typing
 
 
 class MyFormatter(string.Formatter):
@@ -15,20 +16,21 @@ class MyFormatter(string.Formatter):
 	- u: The first character of the inserted string will be converted to upper case.
 	"""
 
-	def format_field(self, value, format_spec):
+	def format_field(self, value: object, format_spec: str) -> str:
 		if not format_spec:
-			return super().format_field(value, format_spec)
+			return typing.cast(str, super().format_field(value, format_spec))
 
-		if format_spec[0] == 'l':
-			format_spec = format_spec[1:]
-			if value:
-				value = value[0].lower() + value[1:]
-		elif format_spec[0] == 'u':
-			format_spec = format_spec[1:]
-			if value:
-				value = value[0].upper() + value[1:]
+		if isinstance(value, str):
+			if format_spec[0] == 'l':
+				format_spec = format_spec[1:]
+				if value:
+					value = value[0].lower() + value[1:]
+			elif format_spec[0] == 'u':
+				format_spec = format_spec[1:]
+				if value:
+					value = value[0].upper() + value[1:]
 
-		return super().format_field(value, format_spec)
+		return typing.cast(str, super().format_field(value, format_spec))
 
 
 formatter = MyFormatter()
